# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mekadb_client.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13mekadb_client.proto\x12\rmekadb_client\"_\n\x07\x41uthReq\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x03 \x01(\t\x12\x13\n\x06schema\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_schema\"X\n\x07\x41uthCtx\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\x12\r\n\x05token\x18\x03 \x01(\t\x12\x1c\n\x14token_system_version\x18\x04 \x01(\x05\"\xd1\x01\n\nSqlRequest\x12\x12\n\nrequest_id\x18\x01 \x01(\x03\x12$\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x16.mekadb_client.AuthCtx\x12\r\n\x05query\x18\x03 \x01(\t\x12\x39\n\x07numeric\x18\x04 \x01(\x0b\x32&.mekadb_client.NumericQueryPlaceholderH\x00\x12\x35\n\x05named\x18\x05 \x01(\x0b\x32$.mekadb_client.NamedQueryPlaceHolderH\x00\x42\x08\n\x06params\"\xb6\x01\n\x10PlaceholderValue\x12\x0f\n\x05i32_t\x18\x01 \x01(\x05H\x00\x12\x0f\n\x05i64_t\x18\x02 \x01(\x03H\x00\x12\x11\n\x07\x66loat_t\x18\x03 \x01(\x02H\x00\x12\x12\n\x08\x64ouble_t\x18\x04 \x01(\x01H\x00\x12\x10\n\x06\x62ool_t\x18\x05 \x01(\x08H\x00\x12\x0f\n\x05str_t\x18\x06 \x01(\tH\x00\x12\x12\n\x08\x62inary_t\x18\x07 \x01(\x0cH\x00\x12\x1a\n\x10timestamp_millis\x18\x08 \x01(\x03H\x00\x42\x06\n\x04\x64\x61ta\"I\n\x17NumericQueryPlaceholder\x12.\n\x05value\x18\x01 \x03(\x0b\x32\x1f.mekadb_client.PlaceholderValue\"O\n\x0fPlaceholderPair\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.mekadb_client.PlaceholderValue\"G\n\x15NamedQueryPlaceHolder\x12.\n\x06values\x18\x01 \x03(\x0b\x32\x1e.mekadb_client.PlaceholderPair\"r\n\x0bSqlResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\x03\x12\x12\n\x08response\x18\x02 \x01(\tH\x00\x12\x30\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x1f.mekadb_client.SqlResponseErrorH\x00\x42\t\n\x07payload\"1\n\x10SqlResponseError\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t2\xa4\x01\n\x0cMekaDBClient\x12@\n\x0c\x61uthenticate\x12\x16.mekadb_client.AuthReq\x1a\x16.mekadb_client.AuthCtx\"\x00\x12R\n\x13SqlWithJsonResponse\x12\x19.mekadb_client.SqlRequest\x1a\x1a.mekadb_client.SqlResponse\"\x00(\x01\x30\x01\x42/\n\x16\x61pp.hypi.mekadb.clientB\x13MekaDBClientWrapperP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mekadb_client_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026app.hypi.mekadb.clientB\023MekaDBClientWrapperP\001'
  _globals['_AUTHREQ']._serialized_start=38
  _globals['_AUTHREQ']._serialized_end=133
  _globals['_AUTHCTX']._serialized_start=135
  _globals['_AUTHCTX']._serialized_end=223
  _globals['_SQLREQUEST']._serialized_start=226
  _globals['_SQLREQUEST']._serialized_end=435
  _globals['_PLACEHOLDERVALUE']._serialized_start=438
  _globals['_PLACEHOLDERVALUE']._serialized_end=620
  _globals['_NUMERICQUERYPLACEHOLDER']._serialized_start=622
  _globals['_NUMERICQUERYPLACEHOLDER']._serialized_end=695
  _globals['_PLACEHOLDERPAIR']._serialized_start=697
  _globals['_PLACEHOLDERPAIR']._serialized_end=776
  _globals['_NAMEDQUERYPLACEHOLDER']._serialized_start=778
  _globals['_NAMEDQUERYPLACEHOLDER']._serialized_end=849
  _globals['_SQLRESPONSE']._serialized_start=851
  _globals['_SQLRESPONSE']._serialized_end=965
  _globals['_SQLRESPONSEERROR']._serialized_start=967
  _globals['_SQLRESPONSEERROR']._serialized_end=1016
  _globals['_MEKADBCLIENT']._serialized_start=1019
  _globals['_MEKADBCLIENT']._serialized_end=1183
# @@protoc_insertion_point(module_scope)
